Command Line Interface
=======================

Tarakimu provides a command line program which which is usually added to
your system path during installation.

Usage
-----

.. click:: tarakimu.cli:cli
   :prog: tarakimu
   :show-nested:
